@@ -1,21 +1,9 @@
-/**
- * Copyright (C) 2018 Michael Reeves reeves.87@gmail.com
- *
- * This file is part of KDiff3.
- *
- * KDiff3 is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 2 of the License, or
- * (at your option) any later version.
- *
- * KDiff3 is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with KDiff3.  If not, see <http://www.gnu.org/licenses/>.
- */
+/*
+ * KDiff3 - Text Diff And Merge Tool
+ * 
+ * SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef DIRECTORYINFO_H
 #define DIRECTORYINFO_H
 
@@ -25,7 +13,8 @@
 class DirectoryInfo
 {
     public:
-      explicit DirectoryInfo(){};
+      explicit DirectoryInfo() = default;
+      
       DirectoryInfo(FileAccess& dirA, FileAccess& dirB, FileAccess& dirC, FileAccess& dirDest)
       {
           m_dirA = dirA;
@@ -38,10 +27,10 @@ class DirectoryInfo
           m_dirListC.clear();
       }
 
-      inline FileAccess dirA() const { return m_dirA; }
-      inline FileAccess dirB() const { return m_dirB; }
-      inline FileAccess dirC() const { return m_dirC; }
-      inline FileAccess destDir() const
+      inline const FileAccess& dirA() const { return m_dirA; }
+      inline const FileAccess& dirB() const { return m_dirB; }
+      inline const FileAccess& dirC() const { return m_dirC; }
+      inline const FileAccess& destDir() const
       {
           if(m_dirDest.isValid())
               return m_dirDest;
